@@ -9,7 +9,7 @@
 #
 package MooseX::AttributeShortcuts;
 {
-  $MooseX::AttributeShortcuts::VERSION = '0.007';
+  $MooseX::AttributeShortcuts::VERSION = '0.010';
 }
 
 # ABSTRACT: Shorthand for common attribute options
@@ -23,10 +23,13 @@ use Moose ();
 use Moose::Exporter;
 use Moose::Util::MetaRole;
 
+# debug...
+#use Smart::Comments;
+
 {
     package MooseX::AttributeShortcuts::Trait::Attribute;
 {
-  $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.007';
+  $MooseX::AttributeShortcuts::Trait::Attribute::VERSION = '0.010';
 }
     use namespace::autoclean;
     use MooseX::Role::Parameterized;
@@ -73,7 +76,6 @@ use Moose::Util::MetaRole;
                     $options->{lazy}     = 1;
                     $options->{builder}  = 1
                         unless $options->{builder} || $options->{default};
-                    $options->{init_arg} = undef unless exists $options->{init_arg};
                 }
             }
 
@@ -153,17 +155,27 @@ sub import {
 sub init_meta {
     shift;
     my %args = @_;
-    my $params = delete $args{role_params} || $role_params || {};
+    my $params = delete $args{role_params} || $role_params || undef;
     undef $role_params;
 
+    # If we're given paramaters to pass on to construct a role with, we build
+    # it out here rather than pass them on and allowing apply_metaroles() to
+    # handle it, as there are Very Loud Warnings about how paramatized roles
+    # are non-cachable when generated on the fly.
+
+    ### $params
+    my $role
+        = ($params && scalar keys %$params)
+        ? MooseX::AttributeShortcuts::Trait::Attribute
+            ->meta
+            ->generate_role(parameters => $params)
+        : 'MooseX::AttributeShortcuts::Trait::Attribute'
+        ;
+
     Moose::Util::MetaRole::apply_metaroles(
-        for => $args{for_class},
-        class_metaroles => {
-            attribute => [ 'MooseX::AttributeShortcuts::Trait::Attribute' => $params ],
-        },
-        role_metaroles => {
-            applied_attribute => [ 'MooseX::AttributeShortcuts::Trait::Attribute' => $params ],
-        },
+        for             => $args{for_class},
+        class_metaroles => { attribute         => [ $role ] },
+        role_metaroles  => { applied_attribute => [ $role ] },
     );
 
     return $args{for_class}->meta;
@@ -175,13 +187,15 @@ sub init_meta {
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 MooseX::AttributeShortcuts - Shorthand for common attribute options
 
 =head1 VERSION
 
-version 0.007
+This document describes version 0.010 of MooseX::AttributeShortcuts - released April 06, 2012 as part of MooseX-AttributeShortcuts.
 
 =head1 SYNOPSIS
 
@@ -190,6 +204,10 @@ version 0.007
     use Moose;
     use MooseX::AttributeShortcuts;
 
+    # same as:
+    #   is => 'ro', lazy => 1, builder => '_build_foo'
+    has foo => (is => 'lazy');
+
     # same as: is => 'ro', writer => '_set_foo'
     has foo => (is => 'rwp');
 
@@ -220,7 +238,7 @@ version 0.007
 
 =head1 DESCRIPTION
 
-Ever find yourself repeatedly specifing writers and builders, because there's
+Ever find yourself repeatedly specifying writers and builders, because there's
 no good shortcut to specifying them?  Sometimes you want an attribute to have
 a read-only public interface, but a private writer.  And wouldn't it be easier
 to just say "builder => 1" and have the attribute construct the canonical
@@ -240,7 +258,7 @@ want to change the defaults, you can ignore the talk about "prefixes" below.
 If you're extending a class and trying to extend its attributes as well,
 you'll find out that the trait is only applied to attributes defined locally
 in the class.  This package exports a trait shortcut function "Shortcuts" that
-will help you apply this in the attribute definition:
+will help you apply this to the extended attribute:
 
     has '+something' => (traits => [Shortcuts], ...);
 
@@ -256,8 +274,6 @@ and writers are named.
 The default writer prefix is '_set_'.  If you'd prefer it to be something
 else (say, '_'), this is where you'd do that.
 
-B<NOTE:> If you're using 0.001, this is a change.  Sorry about that :\
-
 =head2 -builder_prefix
 
     use MooseX::::AttributeShortcuts -builder_prefix => 'prefix';
@@ -278,29 +294,45 @@ various prefixes should be read using the defaults.
 
 =head2 is => 'rwp'
 
-Specifing is => 'rwp' will cause the following options to be set:
+Specifying C<is =E<gt> 'rwp'> will cause the following options to be set:
 
     is     => 'ro'
     writer => "_set_$name"
 
 =head2 is => 'lazy'
 
-Specifing is => 'lazy' will cause the following options to be set:
+Specifying C<is =E<gt> 'lazy'> will cause the following options to be set:
 
     is       => 'ro'
     builder  => "_build_$name"
-    init_arg => undef
     lazy     => 1
 
+B<NOTE:> Since 0.009 we no longer set C<init_arg =E<gt> undef> if no C<init_arg>
+is explicitly provided.  This is a change made in parallel with L<Moo>, based
+on a large number of people surprised that lazy also made one's C<init_def>
+undefined.
+
+=head2 is => 'lazy', default => ...
+
+Specifying C<is =E<gt> 'lazy'> and a default will cause the following options to be
+set:
+
+    is       => 'ro'
+    lazy     => 1
+    default  => ... # as provided
+
+That is, if you specify C<is =E<gt> 'lazy'> and also provide a C<default>, then
+we won't try to set a builder, as well.
+
 =head2 builder => 1
 
-Specifying builder => 1 will cause the following options to be set:
+Specifying C<builder =E<gt> 1> will cause the following options to be set:
 
     builder => "_build_$name"
 
 =head2 clearer => 1
 
-Specifying clearer => 1 will cause the following options to be set:
+Specifying C<clearer =E<gt> 1> will cause the following options to be set:
 
     clearer => "clear_$name"
 
@@ -312,7 +344,7 @@ or, if your attribute name begins with an underscore:
 
 =head2 predicate => 1
 
-Specifying predicate => 1 will cause the following options to be set:
+Specifying C<predicate =E<gt> 1> will cause the following options to be set:
 
     predicate => "has_$name"
 
@@ -324,7 +356,7 @@ or, if your attribute name begins with an underscore:
 
 =head2 trigger => 1
 
-Specifying trigger => 1 will cause the attribute to be created with a trigger
+Specifying C<trigger =E<gt> 1> will cause the attribute to be created with a trigger
 that calls a named method in the class with the options passed to the trigger.
 By default, the method name the trigger calls is the name of the attribute
 prefixed with "_trigger_".
@@ -342,12 +374,19 @@ builder naming scheme (just with a different prefix).
 
 =for Pod::Coverage init_meta
 
+=head1 SOURCE
+
+The development version is on github at L<http://github.com/RsrchBoy/moosex-attributeshortcuts>
+and may be cloned from L<git://github.com/RsrchBoy/moosex-attributeshortcuts.git>
+
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no exception.
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/RsrchBoy/moosex-attributeshortcuts/issues
 
-Please report any bugs to "bug-moosex-attributeshortcuts@rt.cpan.org", or
-through the web interface at <http://rt.cpan.org>.
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
